FrameDetails

Struct FrameDetails 

pub struct FrameDetails {
Show 13 fields pub total_time: f32, pub total_distance: f32, pub max_height: f32, pub max_horizontal_speed: f32, pub max_vertical_speed: f32, pub photo_num: i32, pub video_time: i64, pub aircraft_name: String, pub aircraft_sn: String, pub camera_sn: String, pub rc_sn: String, pub app_platform: Platform, pub app_version: String,
}

Fields

total_time: f32

Total flight time in seconds

total_distance: f32

Total distance flown in meters

max_height: f32

Maximum height reached during the flight in meters

max_horizontal_speed: f32

Maximum horizontal speed reached during the flight in meters per second

max_vertical_speed: f32

Maximum vertical speed reached during the flight in meters per second

photo_num: i32

Number of photos taken during the flight

video_time: i64

Total video recording time in seconds

aircraft_name: String

Name of the aircraft

aircraft_sn: String

Serial number of the aircraft

camera_sn: String

Serial number of the camera

rc_sn: String

Serial number of the remote control

app_platform: Platform

The platform of the app used (e.g., iOS, Android)

app_version: String

Version of the app used