pub struct SmartBattery {Show 17 fields
pub useful_time: u16,
pub go_home_time: u16,
pub land_time: u16,
pub go_home_battery: u16,
pub land_battery: u16,
pub safe_fly_radius: f32,
pub volume_consume: f32,
pub status: u32,
pub go_home_status: BatteryGoHomeStatus,
pub go_home_countdown: u8,
pub voltage: f32,
pub percent: u8,
pub low_warning: u8,
pub low_warning_go_home: u8,
pub serious_low_warning: u8,
pub serious_low_warning_landing: u8,
pub reserve: u8,
}Fields
useful_time: u16go_home_time: u16land_time: u16go_home_battery: u16land_battery: u16safe_fly_radius: f32volume_consume: f32status: u32go_home_status: BatteryGoHomeStatusgo_home_countdown: u8voltage: f32volts
percent: u8low_warning: u8low_warning_go_home: u8serious_low_warning: u8serious_low_warning_landing: u8reserve: u8Trait Implementations
Sourceimpl BinRead for SmartBattery
impl BinRead for SmartBattery
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for SmartBattery
impl Debug for SmartBattery
Sourceimpl ReadEndian for SmartBattery
impl ReadEndian for SmartBattery
Sourceconst ENDIAN: EndianKind
const ENDIAN: EndianKind
The endianness of the type.