pub struct SmartBatteryDynamic {
pub index: u8,
pub current_voltage: f32,
pub current_current: f32,
pub full_capacity: u32,
pub remained_capacity: u32,
pub temperature: f32,
pub cell_count: u8,
pub capacity_percent: u8,
pub battery_state: u64,
}Fields
index: u8current_voltage: f32volts
current_current: f32full_capacity: u32mAh
remained_capacity: u32mAh
temperature: f32degrees
cell_count: u8capacity_percent: u8battery_state: u64Trait Implementations
Sourceimpl BinRead for SmartBatteryDynamic
impl BinRead for SmartBatteryDynamic
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for SmartBatteryDynamic
impl Debug for SmartBatteryDynamic
Sourceimpl ReadEndian for SmartBatteryDynamic
impl ReadEndian for SmartBatteryDynamic
Sourceconst ENDIAN: EndianKind
const ENDIAN: EndianKind
The endianness of the type.